//+------------------------------------------------------------------+
//|                                                     BoxFibo1.mq4 |
//|                                                                  |
//|------------------------------------------------------------------|
//|                                                  24th Sept 2012  |
//|                                                                  |
//|                      Mod by RaptorUK to draw Fib on each new day |
//|                      Changes marked "RaptorUK"                   |
//|                                                                  |
//|------------------------------------------------------------------|
//|                                                  25th Sept 2012  |
//|                                                                  |
//|                      Mod by RaptorUK to draw Fib on last 30 days |
//|                      Changes are NOT marked                      |
//+------------------------------------------------------------------+

#property indicator_chart_window

extern string StartTime    = "01:00";    // time for start of price establishment window
extern string EndTime      = "07:00";    // time for end of price establishment window

extern color  BoxColor     = Blue;
extern color  FiboColor    = Yellow;

//+------------------------------------------------------------------+
int init()  
   {
   //  need to plot the Fibs for the last 30 days . . . not bothering to check for weekends, sorry
   int ObjectIndex = 0;
   
   while(ObjectIndex < 30)
      {
      plot_obj(ObjectIndex, ObjectIndex + 1);
      ObjectIndex++;
      }
   
   return(0);
   }

//+------------------------------------------------------------------+
int deinit()  
   {
   del_obj();
   return(0);
   }

//+------------------------------------------------------------------+
int start()  
   {
   static datetime LastFibTime = 0;                                     //  mod by RaptorUK
  
   if( TimeCurrent() > LastFibTime + ( PERIOD_D1 * 60 ) )              //  mod by RaptorUK
      {
      if( TimeCurrent() > StrToTime(TimeToStr(Time[0],TIME_DATE) + " "  + EndTime + ":00") )  //  mod by RaptorUK
         {
         LastFibTime = StrToTime(TimeToStr(Time[0],TIME_DATE) + " "  + EndTime + ":00");      //  mod by RaptorUK
         plot_obj(FindOldestObj());
         }
      }              //  mod by RaptorUK

   return(0);
   }

//+------------------------------------------------------------------+
void plot_obj(int ObjectIndex, int DayOffset = 0)  
   {
   int ib1, ib2;
   
   datetime dt1 = StrToTime(TimeToStr(Time[0],TIME_DATE) + " "  + StartTime + ":00") - (DayOffset * PERIOD_D1 * 60 );
   datetime dt2 = StrToTime(TimeToStr(Time[0],TIME_DATE) + " "  + EndTime + ":00") - (DayOffset * PERIOD_D1 * 60 );
   ib1 = iBarShift(NULL,0,dt1, true);
   ib2 = iBarShift(NULL,0,dt2, true);
   
   if(ib1 == -1 || ib2 == -1) return;    //  this might take care of weekends . . .
   
   double vHigh = 0, vLow = 999;
   for (int j=ib1; j>ib2; j--)  
      {
      vHigh = MathMax(vHigh,High[j]);
      vLow  = MathMin(vLow,Low[j]);
      }
      
   string objname = StringConcatenate("BF-Box", ObjectIndex);
   if (ObjectFind(objname) > -1) ObjectDelete(objname);      // avoids error generated when trying to create an Object that already exists
   
   ObjectCreate(objname,OBJ_RECTANGLE,0,dt1,vHigh,dt2-60,vLow);
   ObjectSet(objname,OBJPROP_COLOR,BoxColor);

   objname = StringConcatenate("BF-Fibo", ObjectIndex);
   if (ObjectFind(objname) > -1) ObjectDelete(objname);      // avoids error generated when trying to create an Object that already exists
   
   ObjectCreate(objname,OBJ_FIBO,0,dt1,vHigh,dt1 + (Period() * 60 * 2),vLow);
   ObjectSet(objname,OBJPROP_RAY,false);
   ObjectSet(objname,OBJPROP_COLOR,BoxColor);
   ObjectSet(objname,OBJPROP_LEVELCOLOR,FiboColor);
   ObjectSet(objname,OBJPROP_FIBOLEVELS,15);
   ObjectSet(objname,OBJPROP_LEVELSTYLE,STYLE_SOLID);
   ObjectSet(objname,OBJPROP_FIRSTLEVEL,0.0);
   ObjectSet(objname,OBJPROP_FIRSTLEVEL+1,1);
   ObjectSet(objname,OBJPROP_FIRSTLEVEL+2,1.272);
   ObjectSet(objname,OBJPROP_FIRSTLEVEL+3,1.500);
   ObjectSet(objname,OBJPROP_FIRSTLEVEL+4,1.764);
   ObjectSet(objname,OBJPROP_FIRSTLEVEL+5,2.000);
   ObjectSet(objname,OBJPROP_FIRSTLEVEL+6,-0.272);
   ObjectSet(objname,OBJPROP_FIRSTLEVEL+7,-0.500);
   ObjectSet(objname,OBJPROP_FIRSTLEVEL+8,-0.764);
   ObjectSet(objname,OBJPROP_FIRSTLEVEL+9,-1.000);

   ObjectSetFiboDescription(objname,0,"Box = %$");     
   ObjectSetFiboDescription(objname,1,"Box = %$");     
   ObjectSetFiboDescription(objname,2,"Enter = %$");     
   ObjectSetFiboDescription(objname,3,"TP1= %$");     
   ObjectSetFiboDescription(objname,4,"TP2 = %$");     
   ObjectSetFiboDescription(objname,5,"TP3 = %$");     
   ObjectSetFiboDescription(objname,6,"Enter = %$");     
   ObjectSetFiboDescription(objname,7,"TP1 = %$");     
   ObjectSetFiboDescription(objname,8,"TP2 = %$");     
   ObjectSetFiboDescription(objname,9,"TP3 = %$");     
    

   return(0);
   }

//+------------------------------------------------------------------+
void del_obj()  
   {
   int ObjectIndex = 0;
   
   while(ObjectIndex < 30)
      {
      if(ObjectFind(StringConcatenate("BF-Box", ObjectIndex)) > -1)
         ObjectDelete(StringConcatenate("BF-Box", ObjectIndex));
      
      if(ObjectFind(StringConcatenate("BF-Fibo", ObjectIndex)) > -1)
         ObjectDelete(StringConcatenate("BF-Fibo", ObjectIndex));
         
      ObjectIndex++;
      }
   }


//+---------------------------------------------------------------------------+
// Looks through all the Fib objects of the correct name to find the oldest   | 
// so it can be resused. Oldest Fib index is returned                         |
//+---------------------------------------------------------------------------+

int FindOldestObj()
   {
   int ObjectIndex = 0;
   int OldestObject = 0;
   
   while(ObjectIndex < 30)
      {
      if(ObjectIndex == 0 && ObjectFind(StringConcatenate("BF-Fibo", 29)) != -1 && 
         ObjectFind(StringConcatenate("BF-Fibo", 0)) != -1 )
         {
         if(ObjectGet(StringConcatenate("BF-Fibo", 29), OBJPROP_TIME1) < ObjectGet(StringConcatenate("BF-Fibo", 0), OBJPROP_TIME1))
            OldestObject = 29;
         
         ObjectIndex++;
         continue;
         }

      if(ObjectFind(StringConcatenate("BF-Fibo", ObjectIndex)) != -1 )
         {
         if(ObjectGet(StringConcatenate("BF-Fibo", ObjectIndex), OBJPROP_TIME1) < ObjectGet(StringConcatenate("BF-Fibo", OldestObject), OBJPROP_TIME1))
            OldestObject = ObjectIndex;
         }
               
      ObjectIndex++;
      }
      
   return(OldestObject);
   }